Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Lex V2.

Actions, resources, and condition keys for Amazon Lex V2 - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Lex V2

Amazon Lex V2 (service prefix: `lex` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon Lex V2
- Resource types defined by Amazon Lex V2
- Condition keys for Amazon Lex V2

## Actions defined by Amazon Lex V2

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BuildBotLocale | Grants permission to build an existing bot locale in a bot | Write | bot* |  |
CreateBot | Grants permission to create a new bot and a test bot alias pointing to the DRAFT bot version | Write | bot* |  |
bot alias* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateBotAlias | Grants permission to create a new bot alias in a bot | Write | bot alias* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateBotChannel [permission only] | Grants permission to create a bot channel in an existing bot | Write | bot* |  |
CreateBotLocale | Grants permission to create a new bot locale in an existing bot | Write | bot* |  |
CreateBotVersion | Grants permission to create a new version of an existing bot | Write | bot* |  |
CreateCustomVocabulary [permission only] | Grants permission to create a new custom vocabulary in an existing bot locale | Write | bot* |  |
CreateExport | Grants permission to create an export for an existing resource | Write | bot* |  |
CreateIntent | Grants permission to create a new intent in an existing bot locale | Write | bot* |  |
CreateResourcePolicy | Grants permission to create a new resource policy for a Lex resource | Write | bot |  |
bot alias |  |
CreateSlot | Grants permission to create a new slot in an intent | Write | bot* |  |
CreateSlotType | Grants permission to create a new slot type in an existing bot locale | Write | bot* |  |
CreateUploadUrl | Grants permission to create an upload url for import file | Write |  |  |
DeleteBot | Grants permission to delete an existing bot | Write | bot* |  | lex:DeleteBotAlias lex:DeleteBotChannel lex:DeleteBotLocale lex:DeleteBotVersion lex:DeleteIntent lex:DeleteSlot lex:DeleteSlotType
bot alias* |  |
DeleteBotAlias | Grants permission to delete an existing bot alias in a bot | Write | bot alias* |  |
DeleteBotChannel [permission only] | Grants permission to delete an existing bot channel | Write | bot* |  |
DeleteBotLocale | Grants permission to delete an existing bot locale in a bot | Write | bot* |  | lex:DeleteIntent lex:DeleteSlot lex:DeleteSlotType
DeleteBotVersion | Grants permission to delete an existing bot version | Write | bot* |  |
DeleteCustomVocabulary | Grants permission to delete an existing custom vocabulary in a bot locale | Write | bot* |  |
DeleteExport | Grants permission to delete an existing export | Write | bot* |  |
DeleteImport | Grants permission to delete an existing import | Write | bot* |  |
DeleteIntent | Grants permission to delete an existing intent in a bot locale | Write | bot* |  |
DeleteResourcePolicy | Grants permission to delete an existing resource policy for a Lex resource | Write | bot |  |
bot alias |  |
DeleteSession | Grants permission to delete session information for a bot alias and user ID | Write | bot alias* |  |
DeleteSlot | Grants permission to delete an existing slot in an intent | Write | bot* |  |
DeleteSlotType | Grants permission to delete an existing slot type in a bot locale | Write | bot* |  |
DeleteUtterances | Grants permission to delete utterance data for a bot | Write | bot* |  |
DescribeBot | Grants permission to retrieve an existing bot | Read | bot* |  |
DescribeBotAlias | Grants permission to retrieve an existing bot alias | Read | bot alias* |  |
DescribeBotChannel [permission only] | Grants permission to retrieve an existing bot channel | Read | bot* |  |
DescribeBotLocale | Grants permission to retrieve an existing bot locale | Read | bot* |  |
DescribeBotRecommendation | Grants permission to retrieve metadata information about a bot recommendation | Read | bot* |  |
DescribeBotVersion | Grants permission to retrieve an existing bot version | Read | bot* |  |
DescribeCustomVocabulary [permission only] | Grants permission to retrieve an existing custom vocabulary | Read | bot* |  |
DescribeCustomVocabularyMetadata | Grants permission to retrieve metadata of an existing custom vocabulary | Read | bot* |  |
DescribeExport | Grants permission to retrieve an existing export | Read | bot* |  | lex:DescribeBot lex:DescribeBotLocale lex:DescribeIntent lex:DescribeSlot lex:DescribeSlotType lex:ListBotLocales lex:ListIntents lex:ListSlotTypes lex:ListSlots
DescribeImport | Grants permission to retrieve an existing import | Read | bot* |  |
DescribeIntent | Grants permission to retrieve an existing intent | Read | bot* |  |
DescribeResourcePolicy | Grants permission to retrieve an existing resource policy for a Lex resource | Read | bot |  |
bot alias |  |
DescribeSlot | Grants permission to retrieve an existing slot | Read | bot* |  |
DescribeSlotType | Grants permission to retrieve an existing slot type | Read | bot* |  |
GetSession | Grants permission to retrieve session information for a bot alias and user ID | Read | bot alias* |  |
ListAggregatedUtterances | Grants permission to list utterances and statistics for a bot | List | bot* |  |
ListBotAliases | Grants permission to list bot aliases in an bot | List | bot* |  |
ListBotChannels [permission only] | Grants permission to list bot channels | List | bot* |  |
ListBotLocales | Grants permission to list bot locales in a bot | List | bot* |  |
ListBotRecommendations | Grants permission to get a list of bot recommendations that meet the specified criteria | List | bot* |  |
ListBotVersions | Grants permission to list existing bot versions | List | bot* |  |
ListBots | Grants permission to list existing bots | List |  |  |
ListBuiltInIntents | Grants permission to list built-in intents | List |  |  |
ListBuiltInSlotTypes | Grants permission to list built-in slot types | List |  |  |
ListExports | Grants permission to list existing exports | List |  |  |
ListImports | Grants permission to list existing imports | List |  |  |
ListIntents | Grants permission to list intents in a bot | List | bot* |  |
ListRecommendedIntents | Grants permission to get a list of recommended intents provided by the bot recommendation | List | bot* |  |
ListSlotTypes | Grants permission to list slot types in a bot | List | bot* |  |
ListSlots | Grants permission to list slots in an intent | List | bot* |  |
ListTagsForResource | Grants permission to lists tags for a Lex resource | Read | bot |  |
bot alias |  |
PutSession | Grants permission to create a new session or modify an existing session for a bot alias and user ID | Write | bot alias* |  |
RecognizeText | Grants permission to send user input (text-only) to an bot alias | Write | bot alias* |  |
RecognizeUtterance | Grants permission to send user input (text or speech) to an bot alias | Write | bot alias* |  |
SearchAssociatedTranscripts | Grants permission to search for associated transcripts that meet the specified criteria | List | bot* |  |
StartBotRecommendation | Grants permission to start a bot recommendation for an existing bot locale | Write | bot* |  |
StartConversation | Grants permission to stream user input (speech/text/DTMF) to a bot alias | Write | bot alias* |  |
StartImport | Grants permission to start a new import with the uploaded import file | Write | bot |  | lex:CreateBot lex:CreateBotLocale lex:CreateIntent lex:CreateSlot lex:CreateSlotType lex:DeleteBotLocale lex:DeleteIntent lex:DeleteSlot lex:DeleteSlotType lex:UpdateBot lex:UpdateBotLocale lex:UpdateIntent lex:UpdateSlot lex:UpdateSlotType
bot alias |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
TagResource | Grants permission to add or overwrite tags of a Lex resource | Tagging | bot |  |
bot alias |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to remove tags from a Lex resource | Tagging | bot |  |
bot alias |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UpdateBot | Grants permission to update an existing bot | Write | bot* |  |
UpdateBotAlias | Grants permission to update an existing bot alias | Write | bot alias* |  |
UpdateBotLocale | Grants permission to update an existing bot locale | Write | bot* |  |
UpdateBotRecommendation | Grants permission to update an existing bot recommendation request | Write | bot* |  |
UpdateCustomVocabulary [permission only] | Grants permission to update an existing custom vocabulary | Write | bot* |  |
UpdateExport | Grants permission to update an existing export | Write | bot* |  |
UpdateIntent | Grants permission to update an existing intent | Write | bot* |  |
UpdateResourcePolicy | Grants permission to update an existing resource policy for a Lex resource | Write | bot |  |
bot alias |  |
UpdateSlot | Grants permission to update an existing slot | Write | bot* |  |
UpdateSlotType | Grants permission to update an existing slot type | Write | bot* |  |

## Resource types defined by Amazon Lex V2

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
bot | `arn:$ { Partition}:lex:$ { Region}:$ { Account}:bot/$ { BotId}` | aws:ResourceTag/${TagKey}
bot alias | `arn:$ { Partition}:lex:$ { Region}:$ { Account}:bot-alias/$ { BotId}/$ { BotAliasId}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Lex V2

Amazon Lex V2 defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tags in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags attached to a Lex resource | String
aws:TagKeys | Filters access by the set of tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.